import { Db, ObjectId } from 'mongodb'

import { mainDb } from '../../utils/mongo'
import { cleanId } from '../../utils/common'
import { draftsCollection, tasksCollection, numberCollection } from '../../__data__/constants'

export const createTask = async ({ userId }) => {
    const db: Db = await mainDb

    const col = db.collection(draftsCollection)
    const ncol = db.collection(numberCollection)

    const numberObject = await ncol.findOne({})
    if (!numberObject) {
        await ncol.insertOne({ number: 1 })
    }

    ncol.updateOne({}, {
        $set: {
            number: (numberObject?.number || 1) + 1
        }
    })

    const draftTask = {
        cratedBy: new ObjectId(userId),
        createdDt: Date.now(),
        lastModufy: Date.now(),
        names: {
            'ru': 'Полиндром'
        },
        'draft': true,
        'number': (numberObject?.number || 1) + 1,
        'markdown': '# Напишите функцию проверки текста на полиндром\\n## Напишите функцию проверки текста на полиндром\\n### Напишите функцию проверки текста на полиндром\\n#### Напишите функцию проверки текста на полиндром\\n##### Напишите функцию проверки текста на полиндром\\n###### Напишите функцию проверки текста на полиндром\\n\\nБлок текста с описанием задачи.\\n[Ссылка](https://reactjs.org/) на документацию реакта\\n\\nНе забудьте [зарегистрироваться](/auth) и [поискать](/main) задачки\\n\\n![react logo](https://tproger.ru/s3/uploads/2016/10/reactmini.png)\\n\\n![line](https://www.clipartmax.com/png/small/44-446497_lines-clipart-vertical-line-blue-vertical-line-png.png)\\n\\n> цитата\\n> цитата\\n> цитата\\n\\n```javascript\\nimport { useCallback, useRef, useEffect } from \'react\';\\nimport { editor as mEditor } from \'monaco-editor\';\\n\\nexport const useMonako = (inputData, remountFlag, language: string, onChange = (value: string) => null) => {\\n    const editorRef = useRef<mEditor.IStandaloneCodeEditor>();\\n    const nodeRef = useRef(null);\\n    const remount = useCallback(() => {\\n        editorRef.current?.dispose();\\n        editorRef.current = mEditor.create(nodeRef.current, {\\n            value: inputData,\\n            theme: \'light\' === \'light\' ? \'vs\' : \'vs-dark\',\\n            language,\\n        });\\n\\n        const model = editorRef.current.getModel();\\n        model.onDidChangeContent(() => {\\n            const value = model.getValue();\\n            onChange(value)\\n        });\\n    } ,[inputData, nodeRef]);\\n\\n    useEffect(() => {\\n        try {\\n            setTimeout(() => {\\n                if (nodeRef.current) {\\n                    remount();\\n\\n                    () => {\\n                        editorRef.current.dispose();\\n                        editorRef.current = null;\\n                    };\\n                }\\n            }, 2);\\n        } catch (error) {\\n            console.error(error);\\n        }\\n    }, [nodeRef, remountFlag]);\\n\\n    return {\\n        nodeRef,\\n        getValue: () => editorRef?.current?.getValue(),\\n    };\\n}\\n\\n```'
    }

    await col.insertOne(draftTask)

    return cleanId(draftTask)
}

export const getTaskData = async (taskId) => {
    const db: Db = await mainDb

    const col = db.collection(draftsCollection)

    const task = await col.findOne({
        _id: new ObjectId(taskId),
    }).catch(console.log)

    return cleanId(task)
}

export const getDrafts = async (userId) => {
    const db: Db = await mainDb

    const col = db.collection(draftsCollection)
    const tasks = await col.find({
        cratedBy: new ObjectId(userId),
    }).toArray()

    return cleanId(tasks)
}
